==> ts-pfsense_2.00-01.txz: opt/threatstop/templates/pfsense/tslogupload.php <==
<?php
/**
 *
 * Copyright(c) 2006-2019 ThreatSTOP, Inc. All Rights Reserved
 *
 * NOTICE: All information contained herein is, and remains the property
 * of ThreatSTOP, Inc. and its suppliers, if any. The intellectual and
 * technical concepts contained herein are proprietary to ThreatSTOP, Inc.
 * and its suppliers and certain aspects thereof are protected by United
 * States Patent No. 8,533,822 and United States Patent No. 8,869,237,
 * and are protected by trade secret or copyright law.
 *
 * US Government Entities: The ThreatSTOP service, software and
 * documentation, as applicable, are "commercial computer software" and
 * "commercial computer software documentation" developed exclusively at
 * private expense by Threatstop, Inc. ("Threatstop"). Pursuant to FAR
 * 12.212 or DFARS 227 7202 and their successors, as applicable, use,
 * reproduction and disclosure of the software and documentation is
 * governed by the terms of Threatstop's commercial agreement.
 */

require_once("/usr/local/www/threatstop.conf.php"); // TDID

ini_set('display_startup_errors', 1);
ini_set('display_errors', 1);
error_reporting(-1);

$options = getopt('', ['force']);

# if minute is an interval of $interval, upload, else spool.
# this makes it so you can run multiple times and it will spool / stage log lines
# but only send when interval is matched (no modulus) or --force flag added.
$interval = 15;

// echo "dump" . var_dump($TS_CONFIG) ."\n";
// echo "dump" . var_dump($options) ."\n";
// if ( array_key_exists('force', $options)) {
//         echo "Forced upload";
//     }
$LOGUPLOAD_STATUS = $TS_CONFIG["logupload"];
// echo "LogUpload [$LOGUPLOAD_STATUS]";
if ($LOGUPLOAD_STATUS != 'enabled') {
    die("Log uploads are disabled. Please reconfigure or re-install to enable via installation prompts");
}
$TSDIR = $TS_CONFIG["src"];
echo "Starting ThreatSTOP log uploader ". date('Y/m/d H:i:s') . "\n";
function set_telemetry($key, $value=false) {
    $TSDIR = $GLOBALS['TSDIR'];
    if (! $value) {
        # just touch file
        shell_exec("touch $TSDIR/.$key");
        echo "updating telem mtime: $key\n";
    } else {
        shell_exec("printf '$value' > $TSDIR/.$key");
        echo "updating telem: $key => $value\n";
    }

}

$spool_file = "$TSDIR/.log_spool"; # file we will store temp log lines until we send
$timestamp_file = "$TSDIR/.last_time_log_spooled"; # file we store last read timestamp into
// $content = fopen($TS_CONFIG["logfile"], 'r');

$last_timestamp = 0;
if (file_exists($timestamp_file)) {
    $last_timestamp = file_get_contents($timestamp_file);
}

// echo "last resumable timestamp from file or zero: $last_timestamp \n";
// $i = 0;
$has_new_loglines = false;

foreach (explode("\n", shell_exec("sudo $TS_CONFIG[clog] $TS_CONFIG[logfile]")) as $line) {
    if (strpos($line, 'filterlog') == false) {
        // $i++;
        // echo "non-filterline: $line";
        continue;
    }
    $beginning = explode('filterlog:', preg_replace('!\s+!', ' ', $line))[0]; # shrink whitespace
    $date_string = implode(' ', array_slice(explode(' ', $beginning), 0, 3));
    // echo "date part: [$date_string]";
    if (! $date_string) {
        continue;
    }

    $timestamp = strtotime($date_string);
    // print "Is timestamp: $timestamp > $last_timestamp \n";
    if (! $timestamp or $timestamp < 1555000000 ) {
        continue;
    }
    // echo "strtotime: $timestamp \n";
    if ($timestamp > $last_timestamp) {
        print "[Adding line]: '$line'\n";
        // print "[Adding line]: '$timestamp'\n";

        shell_exec("echo '$line' >> $spool_file");
        $has_new_loglines = true;
        $last_timestamp = $timestamp;
    }
    // else {
        // print "[Skipping line]: '$line'\n";
        // print "[Skipping line]: '$timestamp'\n";


    // }

}


// set new timestamp
if ($has_new_loglines) {
    echo "\n setting resume timestamp: $last_timestamp \n";
    shell_exec("printf '$last_timestamp' > $timestamp_file");
}

$now_minute = date ("i", time());

if ($now_minute % $interval == 0 ||  array_key_exists('force', $options)) {
    // set telemetry so we know we are attempting to send something
    set_telemetry('last_log_upload_attempt');
    if ( array_key_exists('force', $options)) {
        echo "Forcing upload...\n";
    } else {
        echo "Uploading content per every $interval minutes\n";
    }

    if (!file_exists($spool_file)) {
        die("$spool_file not found, there is nothing to send.\n");
    }

    $content = file_get_contents($spool_file);  # all the data in the spool log
    // echo "Resuming at: $startpos >> $lines[$startpos] ";
    // $nl = explode("\n", $content);
    // echo "first line: $nl[0]\n";
    // print "content: $content";
    // die('stopping here for testing....');
    $ip      = 'ssl://logs.threatstop.com';
    $host    = 'logs.threatstop.com';
    $md5     = md5($content);
    $len     = strlen($content);

    # Don't upload if no log present
    if ($len == 0) {
        exit;
    }

    //echo "$md5 $len\n";
    $sp = fsockopen($ip, 443, $errno, $errstr, 10);

    if (!$sp) {
        set_telemetry("log_upload_status", "failure");
        echo "\nLog upload [Failure]\n";
        die("error: $errstr ($errno)" . "\r\n");
    }

    $boundary = str_repeat('-', 10) . time();

    $body = '--' . $boundary . "\r\n";
    $body .= "Content-Disposition: form-data; name=\"md5_client\"\r\n\r\n";
    $body .= $md5."\r\n";
    $body .= '--' . $boundary . "\r\n";
    $body .= "Content-Disposition: form-data; name=\"upfile_size\"\r\n\r\n";
    $body .= "$len\r\n";
    $body .= '--' . $boundary . "\r\n";
    if ($TDID) {
      $body .= "Content-Disposition: form-data; name=\"fw_tdid\"\r\n\r\n";
      $body .= "$TDID\r\n";
      $body .= '--' . $boundary . "\r\n";
    }
    //$body .= "Content-Disposition: form-data; name=\"fw_ip\"\r\n\r\n";
    //$body .= $ip"\r\n";
    //$body .= '--' . $boundary . "\r\n";
    $body .= "Content-Disposition: form-data; name=\"upfile\"; filename=\"log\"\r\n";
    $body .= "Content-Type: text/plain\r\n";
    $body .= "Content-Transfer-Encoding: binary\r\n\r\n";
    $body .= $content . "\r\n";
    $body .= "--$boundary--\r\n";

    $query  = 'POST /cgi-bin/logupload.pl HTTP/1.1' . "\r\n";
    $query .= 'HOST: ' . $host . "\r\n";
    $query .= 'Content-type: multipart/form-data; boundary=' . $boundary . "\r\n";
    $query .= 'Connection: Keep-Alive' . "\r\n";
    $query .= 'Content-Length: ' . strlen($body) . "\r\n";
    $query .= "Accept:*/*\r\n\r\n";
    $query .= $body;

    $result = fwrite($sp, $query . "\r\n");
    $result2 = fread($sp, 10000000);
    //var_dump($result, $result2);
    if (strpos($result2, 'HTTP/1.1 200 OK') !== false) {
        set_telemetry("log_upload_status", "success");
        echo "\nLog upload [Success]\n";
        unlink($spool_file);
    } else {
        set_telemetry("log_upload_status", "failure");
        echo "\nLog upload [Failure]\n";
    }
}




?>

==> ts-pfsense-2.02-02.txz: opt/threatstop/templates/pfsense/tslogupload.php <==
<?php
/**
 *
 * Copyright(c) 2006-2020 ThreatSTOP, Inc. All Rights Reserved
 *
 * NOTICE: All information contained herein is, and remains the property
 * of ThreatSTOP, Inc. and its suppliers, if any. The intellectual and
 * technical concepts contained herein are proprietary to ThreatSTOP, Inc.
 * and its suppliers and certain aspects thereof are protected by United
 * States Patent No. 8,533,822 and United States Patent No. 8,869,237,
 * and are protected by trade secret or copyright law.
 *
 * US Government Entities: The ThreatSTOP service, software and
 * documentation, as applicable, are "commercial computer software" and
 * "commercial computer software documentation" developed exclusively at
 * private expense by Threatstop, Inc. ("Threatstop"). Pursuant to FAR
 * 12.212 or DFARS 227 7202 and their successors, as applicable, use,
 * reproduction and disclosure of the software and documentation is
 * governed by the terms of Threatstop's commercial agreement.
 */

require_once("/usr/local/www/threatstop.conf.php"); // TDID

ini_set('display_startup_errors', 1);
ini_set('display_errors', 1);
error_reporting(-1);

$options = getopt('', ['force']);

# if minute is an interval of $interval, upload, else spool.
# this makes it so you can run multiple times and it will spool / stage log lines
# but only send when interval is matched (no modulus) or --force flag added.
$interval = 15;

// echo "dump" . var_dump($TS_CONFIG) ."\n";
// echo "dump" . var_dump($options) ."\n";
// if ( array_key_exists('force', $options)) {
//         echo "Forced upload";
//     }
$LOGUPLOAD_STATUS = $TS_CONFIG["logupload"];
echo "LogUpload [$LOGUPLOAD_STATUS]";
if ($LOGUPLOAD_STATUS != 'enabled') {
    die("Log uploads are disabled. Please reconfigure or re-install to enable via installation prompts");
}
$TSDIR = $TS_CONFIG["src"];
echo "Starting ThreatSTOP log uploader ". date('Y/m/d H:i:s') . "\n";
function set_telemetry($key, $value=false) {
    $TSDIR = $GLOBALS['TSDIR'];
    if (! $value) {
        # just touch file
        shell_exec("touch $TSDIR/.$key");
        echo "updating telem mtime: $key\n";
    } else {
        shell_exec("printf '$value' > $TSDIR/.$key");
        echo "updating telem: $key => $value\n";
    }

}

$spool_file = "$TSDIR/.log_spool"; # file we will store temp log lines until we send
$timestamp_file = "$TSDIR/.last_time_log_spooled"; # file we store last read timestamp into
// $content = fopen($TS_CONFIG["logfile"], 'r');

$last_timestamp = 0;
if (file_exists($timestamp_file)) {
    $last_timestamp = file_get_contents($timestamp_file);
}

echo "last resumable timestamp from file or zero: $last_timestamp \n";
// $i = 0;
$has_new_loglines = false;

# GS-2622 as of pfsense 2.5 clog was removed.. use cat instead if clog does not exist
$LOGAPP = trim(shell_exec("which clog"));
if ($LOGAPP !== "") {
    echo "LOG READER: $LOGAPP";
} else {
    $LOGAPP = trim(shell_exec("which cat"));
    echo "LOG READER: $LOGAPP";
}

foreach (explode("\n", shell_exec("sudo $LOGAPP $TS_CONFIG[logfile]")) as $line) {
    if (strpos($line, 'filterlog') == false) {
        // $i++;
        // echo "non-filterline: $line";
        continue;
    }
    $beginning = explode('filterlog:', preg_replace('!\s+!', ' ', $line))[0]; # shrink whitespace
    $date_string = implode(' ', array_slice(explode(' ', $beginning), 0, 3));
    // echo "date part: [$date_string]";
    if (! $date_string) {
        continue;
    }

    $timestamp = strtotime($date_string);
    // print "Is timestamp: $timestamp > $last_timestamp \n";
    if (! $timestamp or $timestamp < 1555000000 ) {
        continue;
    }
    // echo "strtotime: $timestamp \n";
    if ($timestamp > $last_timestamp) {
        print "[Adding line]: '$line'\n";
        // print "[Adding line]: '$timestamp'\n";

        shell_exec("echo '$line' >> $spool_file");
        $has_new_loglines = true;
        $last_timestamp = $timestamp;
    } else {
        print "[Skipping line]: '$line'\n";
        // print "[Skipping line]: '$timestamp'\n";


    }

}


// set new timestamp
if ($has_new_loglines) {
    echo "\n setting resume timestamp: $last_timestamp \n";
    shell_exec("printf '$last_timestamp' > $timestamp_file");
}

$now_minute = date ("i", time());

if ($now_minute % $interval == 0 ||  array_key_exists('force', $options)) {
    // set telemetry so we know we are attempting to send something
    set_telemetry('last_log_upload_attempt');
    if ( array_key_exists('force', $options)) {
        echo "Forcing upload...\n";
    } else {
        echo "Uploading content per every $interval minutes\n";
    }

    if (!file_exists($spool_file)) {
        die("$spool_file not found, there is nothing to send.\n");
    }

    $content = file_get_contents($spool_file);  # all the data in the spool log
    // echo "Resuming at: $startpos >> $lines[$startpos] ";
    // $nl = explode("\n", $content);
    // echo "first line: $nl[0]\n";
    // print "content: $content";
    // die('stopping here for testing....');
    $ip      = 'ssl://logs.threatstop.com';
    $host    = 'logs.threatstop.com';
    $md5     = md5($content);
    $len     = strlen($content);

    # Don't upload if no log present
    if ($len == 0) {
        exit;
    }

    //echo "$md5 $len\n";
    $sp = fsockopen($ip, 443, $errno, $errstr, 10);

    if (!$sp) {
        set_telemetry("log_upload_status", "failure");
        echo "\nLog upload [Failure]\n";
        die("error: $errstr ($errno)" . "\r\n");
    }

    $boundary = str_repeat('-', 10) . time();

    $body = '--' . $boundary . "\r\n";
    $body .= "Content-Disposition: form-data; name=\"md5_client\"\r\n\r\n";
    $body .= $md5."\r\n";
    $body .= '--' . $boundary . "\r\n";
    $body .= "Content-Disposition: form-data; name=\"upfile_size\"\r\n\r\n";
    $body .= "$len\r\n";
    $body .= '--' . $boundary . "\r\n";
    if ($TDID) {
      $body .= "Content-Disposition: form-data; name=\"fw_tdid\"\r\n\r\n";
      $body .= "$TDID\r\n";
      $body .= '--' . $boundary . "\r\n";
    }
    //$body .= "Content-Disposition: form-data; name=\"fw_ip\"\r\n\r\n";
    //$body .= $ip"\r\n";
    //$body .= '--' . $boundary . "\r\n";
    $body .= "Content-Disposition: form-data; name=\"upfile\"; filename=\"log\"\r\n";
    $body .= "Content-Type: text/plain\r\n";
    $body .= "Content-Transfer-Encoding: binary\r\n\r\n";
    $body .= $content . "\r\n";
    $body .= "--$boundary--\r\n";

    $query  = 'POST /cgi-bin/logupload.pl HTTP/1.1' . "\r\n";
    $query .= 'HOST: ' . $host . "\r\n";
    $query .= 'Content-type: multipart/form-data; boundary=' . $boundary . "\r\n";
    $query .= 'Connection: Keep-Alive' . "\r\n";
    $query .= 'Content-Length: ' . strlen($body) . "\r\n";
    $query .= "Accept:*/*\r\n\r\n";
    $query .= $body;

    $result = fwrite($sp, $query . "\r\n");
    $result2 = fread($sp, 10000000);
    //var_dump($result, $result2);
    if (strpos($result2, 'HTTP/1.1 200 OK') !== false) {
        set_telemetry("log_upload_status", "success");
        echo "\nLog upload [Success]\n";
        unlink($spool_file);
    } else {
        set_telemetry("log_upload_status", "failure");
        echo "\nLog upload [Failure]\n";
    }
}




?>
